Crate runmat_value

Crate runmat_value 

Re-exports

pub use symbolic::SymbolicExpr;
pub use symbolic::SymbolicFunction;

Modules

symbolic

Structs

CellArray
CharArray
Closure
ComplexTensor
DynamicPropertyDef
ForeignRef
Opaque live foreign-runtime reference. The host registry owns the actual resource; the generation fences stale handles after host/session restart.
ForeignTypeIdentity
HandleRef
IntegerComplexStorage
Listener
Event listener handle for events
LogicalArray
MException
ObjectArray
A homogeneous MATLAB object array.
ObjectInstance
SparseTensor
StringArray
StructValue
SymbolicArray
Tensor

Enums

ComplexStorage
ForeignAffinity
ForeignLifetime
ForeignOwnership
FormatMode
IntValue
IntegerStorage
Exact homogeneous backing storage for MATLAB integer arrays.
NumericDType
NumericScalar
One exact scalar read from or written to NumericStorage.
NumericStorage
Authoritative homogeneous host storage for a real numeric array.
NumericStorageView
Immutable typed view over authoritative real numeric storage.
NumericStorageViewMut
Mutable typed view over authoritative real numeric storage.
Value

Functions

format_number
Format a number using the current thread-local display format.
get_display_format
set_display_format